lsf

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 20, 2026 License: MIT Imports: 10 Imported by: 0

README

lsf

faster recursive ls

lsf is a fast way to recursively list files in a directory and it's children. It acheives this by running concurrent directory traversals, and ignoring any ordering of the directory's contents

A significant portion of the development was aided by the following open-source projects:

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Walk

func Walk(c chan string, p string) error

func WalkWithOptions

func WalkWithOptions(c chan string, p string, opts Options) error

Types

type Options

type Options struct {
	Logger *slog.Logger

	MaxWorkers int
	Ignore     []string
}

Directories

Path Synopsis

Jump to